"""
Generated class for ImmunizationRecommendation. 
Time: 2024-06-14 18:37:49
"""

from fhirmodels.R4B.BackboneElement import *
from fhirmodels.R4B.CodeableConcept import *
from fhirmodels.R4B.DomainResource import *
from fhirmodels.R4B.Extension import *
from fhirmodels.R4B.Identifier import *
from fhirmodels.R4B.Meta import *
from fhirmodels.R4B.Narrative import *
from fhirmodels.R4B.Reference import *
from fhirmodels.R4B.Resource import *


class DateCriterion(FhirBaseModel):
    """Vaccine date recommendations.  For example, earliest date to administer, latest date to administer, etc.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept code: Type of date
    :param str value: Recommended date
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "code": {"class_name": "CodeableConcept", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        code: "CodeableConcept" = None,
        value: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.code = code
        self.value = value

    @classmethod
    def from_dict(cls, data: dict) -> "ImmunizationRecommendation":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ImmunizationRecommendation":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Recommendation(FhirBaseModel):
    """Vaccine administration recommendations.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept vaccineCode: Vaccine  or vaccine group recommendation applies to
    :param CodeableConcept targetDisease: Disease to be immunized against
    :param CodeableConcept contraindicatedVaccineCode: Vaccine which is contraindicated to fulfill the recommendation
    :param CodeableConcept forecastStatus: Vaccine recommendation status
    :param CodeableConcept forecastReason: Vaccine administration status reason
    :param DateCriterion dateCriterion: Dates governing proposed immunization
    :param str description: Protocol details
    :param str series: Name of vaccination series
    :param int doseNumberPositiveInt: Recommended dose number within series
    :param str doseNumberString: Recommended dose number within series
    :param int seriesDosesPositiveInt: Recommended number of doses for immunity
    :param str seriesDosesString: Recommended number of doses for immunity
    :param Reference supportingImmunization: Past immunizations supporting recommendation
    :param Reference supportingPatientInformation: Patient observations supporting recommendation
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "vaccineCode": {"class_name": "CodeableConcept", "is_contained": False},
        "targetDisease": {"class_name": "CodeableConcept", "is_contained": False},
        "contraindicatedVaccineCode": {
            "class_name": "CodeableConcept",
            "is_contained": False,
        },
        "forecastStatus": {"class_name": "CodeableConcept", "is_contained": False},
        "forecastReason": {"class_name": "CodeableConcept", "is_contained": False},
        "dateCriterion": {"class_name": "DateCriterion", "is_contained": True},
        "supportingImmunization": {"class_name": "Reference", "is_contained": False},
        "supportingPatientInformation": {
            "class_name": "Reference",
            "is_contained": False,
        },
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        vaccineCode: list["CodeableConcept"] = None,
        targetDisease: "CodeableConcept" = None,
        contraindicatedVaccineCode: list["CodeableConcept"] = None,
        forecastStatus: "CodeableConcept" = None,
        forecastReason: list["CodeableConcept"] = None,
        dateCriterion: list["DateCriterion"] = None,
        description: "str" = None,
        series: "str" = None,
        doseNumberPositiveInt: "int" = None,
        doseNumberString: "str" = None,
        seriesDosesPositiveInt: "int" = None,
        seriesDosesString: "str" = None,
        supportingImmunization: list["Reference"] = None,
        supportingPatientInformation: list["Reference"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.vaccineCode = vaccineCode or []
        self.targetDisease = targetDisease
        self.contraindicatedVaccineCode = contraindicatedVaccineCode or []
        self.forecastStatus = forecastStatus
        self.forecastReason = forecastReason or []
        self.dateCriterion = dateCriterion or []
        self.description = description
        self.series = series
        self.doseNumberPositiveInt = doseNumberPositiveInt
        self.doseNumberString = doseNumberString
        self.seriesDosesPositiveInt = seriesDosesPositiveInt
        self.seriesDosesString = seriesDosesString
        self.supportingImmunization = supportingImmunization or []
        self.supportingPatientInformation = supportingPatientInformation or []

    @classmethod
    def from_dict(cls, data: dict) -> "ImmunizationRecommendation":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ImmunizationRecommendation":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class ImmunizationRecommendation(DomainResource):
    """A patient's point-in-time set of recommendations (i.e. forecasting) according to a published schedule with optional supporting justification.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param Identifier identifier: Business identifier
    :param Reference patient: Who this profile is for
    :param str date: Date recommendation(s) created
    :param Reference authority: Who is responsible for protocol
    :param Recommendation recommendation: Vaccine administration recommendations
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "patient": {"class_name": "Reference", "is_contained": False},
        "authority": {"class_name": "Reference", "is_contained": False},
        "recommendation": {"class_name": "Recommendation", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        identifier: list["Identifier"] = None,
        patient: "Reference" = None,
        date: "str" = None,
        authority: "Reference" = None,
        recommendation: list["Recommendation"] = None,
    ):

        self.resourceType = "ImmunizationRecommendation"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.identifier = identifier or []
        self.patient = patient
        self.date = date
        self.authority = authority
        self.recommendation = recommendation or []

    @classmethod
    def from_dict(cls, data: dict) -> "ImmunizationRecommendation":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ImmunizationRecommendation":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for ImagingSelection. 
Time: 2024-06-14 18:37:55
"""

from fhirmodels.R5.BackboneElement import *
from fhirmodels.R5.CodeableConcept import *
from fhirmodels.R5.CodeableReference import *
from fhirmodels.R5.Coding import *
from fhirmodels.R5.DomainResource import *
from fhirmodels.R5.Extension import *
from fhirmodels.R5.Identifier import *
from fhirmodels.R5.Meta import *
from fhirmodels.R5.Narrative import *
from fhirmodels.R5.Reference import *
from fhirmodels.R5.Resource import *


class Performer(FhirBaseModel):
    """Selector of the instances – human or machine.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept function: Type of performer
    :param Reference actor: Author (human or machine)
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "function": {"class_name": "CodeableConcept", "is_contained": False},
        "actor": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        function: "CodeableConcept" = None,
        actor: "Reference" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.function = function
        self.actor = actor

    @classmethod
    def from_dict(cls, data: dict) -> "ImagingSelection":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ImagingSelection":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class ImageRegion2D(FhirBaseModel):
    """Each imaging selection instance or frame list might includes an image region, specified by a region type and a set of 2D coordinates.
       If the parent imagingSelection.instance contains a subset element of type frame, the image region applies to all frames in the subset list.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str regionType: point | polyline | interpolated | circle | ellipse
    :param float coordinate: Specifies the coordinates that define the image region
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        regionType: "str" = None,
        coordinate: list["float"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.regionType = regionType
        self.coordinate = coordinate or []

    @classmethod
    def from_dict(cls, data: dict) -> "ImagingSelection":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ImagingSelection":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class ImageRegion3D(FhirBaseModel):
    """Each imaging selection might includes a 3D image region, specified by a region type and a set of 3D coordinates.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str regionType: point | multipoint | polyline | polygon | ellipse | ellipsoid
    :param float coordinate: Specifies the coordinates that define the image region
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        regionType: "str" = None,
        coordinate: list["float"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.regionType = regionType
        self.coordinate = coordinate or []

    @classmethod
    def from_dict(cls, data: dict) -> "ImagingSelection":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ImagingSelection":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Instance(FhirBaseModel):
    """Each imaging selection includes one or more selected DICOM SOP instances.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str uid: DICOM SOP Instance UID
    :param int number: DICOM Instance Number
    :param Coding sopClass: DICOM SOP Class UID
    :param str subset: The selected subset of the SOP Instance
    :param ImageRegion2D imageRegion2D: A specific 2D region in a DICOM image / frame
    :param ImageRegion3D imageRegion3D: A specific 3D region in a DICOM frame of reference
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "sopClass": {"class_name": "Coding", "is_contained": False},
        "imageRegion2D": {"class_name": "ImageRegion2D", "is_contained": True},
        "imageRegion3D": {"class_name": "ImageRegion3D", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        uid: "str" = None,
        number: "int" = None,
        sopClass: "Coding" = None,
        subset: list["str"] = None,
        imageRegion2D: list["ImageRegion2D"] = None,
        imageRegion3D: list["ImageRegion3D"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.uid = uid
        self.number = number
        self.sopClass = sopClass
        self.subset = subset or []
        self.imageRegion2D = imageRegion2D or []
        self.imageRegion3D = imageRegion3D or []

    @classmethod
    def from_dict(cls, data: dict) -> "ImagingSelection":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ImagingSelection":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class ImagingSelection(DomainResource):
    """A selection of DICOM SOP instances and/or frames within a single Study and Series. This might include additional specifics such as an image region, an Observation UID or a Segmentation Number, allowing linkage to an Observation Resource or transferring this information along with the ImagingStudy Resource.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param Identifier identifier: Business Identifier for Imaging Selection
    :param str status: available | entered-in-error | unknown
    :param Reference subject: Subject of the selected instances
    :param str issued: Date / Time when this imaging selection was created
    :param Performer performer: Selector of the instances (human or machine)
    :param Reference basedOn: Associated request
    :param CodeableConcept category: Classifies the imaging selection
    :param CodeableConcept code: Imaging Selection purpose text or code
    :param str studyUid: DICOM Study Instance UID
    :param Reference derivedFrom: The imaging study from which the imaging selection is derived
    :param Reference endpoint: The network service providing retrieval for the images referenced in the imaging selection
    :param str seriesUid: DICOM Series Instance UID
    :param int seriesNumber: DICOM Series Number
    :param str frameOfReferenceUid: The Frame of Reference UID for the selected images
    :param CodeableReference bodySite: Body part examined
    :param Reference focus: Related resource that is the focus for the imaging selection
    :param Instance instance: The selected instances
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "subject": {"class_name": "Reference", "is_contained": False},
        "performer": {"class_name": "Performer", "is_contained": True},
        "basedOn": {"class_name": "Reference", "is_contained": False},
        "category": {"class_name": "CodeableConcept", "is_contained": False},
        "code": {"class_name": "CodeableConcept", "is_contained": False},
        "derivedFrom": {"class_name": "Reference", "is_contained": False},
        "endpoint": {"class_name": "Reference", "is_contained": False},
        "bodySite": {"class_name": "CodeableReference", "is_contained": False},
        "focus": {"class_name": "Reference", "is_contained": False},
        "instance": {"class_name": "Instance", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        identifier: list["Identifier"] = None,
        status: "str" = None,
        subject: "Reference" = None,
        issued: "str" = None,
        performer: list["Performer"] = None,
        basedOn: list["Reference"] = None,
        category: list["CodeableConcept"] = None,
        code: "CodeableConcept" = None,
        studyUid: "str" = None,
        derivedFrom: list["Reference"] = None,
        endpoint: list["Reference"] = None,
        seriesUid: "str" = None,
        seriesNumber: "int" = None,
        frameOfReferenceUid: "str" = None,
        bodySite: "CodeableReference" = None,
        focus: list["Reference"] = None,
        instance: list["Instance"] = None,
    ):

        self.resourceType = "ImagingSelection"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.identifier = identifier or []
        self.status = status
        self.subject = subject
        self.issued = issued
        self.performer = performer or []
        self.basedOn = basedOn or []
        self.category = category or []
        self.code = code
        self.studyUid = studyUid
        self.derivedFrom = derivedFrom or []
        self.endpoint = endpoint or []
        self.seriesUid = seriesUid
        self.seriesNumber = seriesNumber
        self.frameOfReferenceUid = frameOfReferenceUid
        self.bodySite = bodySite
        self.focus = focus or []
        self.instance = instance or []

    @classmethod
    def from_dict(cls, data: dict) -> "ImagingSelection":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ImagingSelection":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for MedicinalProduct. 
Time: 2024-06-14 18:37:17
"""

from fhirmodels.R4.BackboneElement import *
from fhirmodels.R4.CodeableConcept import *
from fhirmodels.R4.Coding import *
from fhirmodels.R4.DomainResource import *
from fhirmodels.R4.Extension import *
from fhirmodels.R4.Identifier import *
from fhirmodels.R4.MarketingStatus import *
from fhirmodels.R4.Meta import *
from fhirmodels.R4.Narrative import *
from fhirmodels.R4.Reference import *
from fhirmodels.R4.Resource import *


class NamePart(FhirBaseModel):
    """Coding words or phrases of the name.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str part: A fragment of a product name
    :param Coding type: Idenifying type for this part of the name (e.g. strength part)
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "type": {"class_name": "Coding", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        part: "str" = None,
        type: "Coding" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.part = part
        self.type = type

    @classmethod
    def from_dict(cls, data: dict) -> "MedicinalProduct":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "MedicinalProduct":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class CountryLanguage(FhirBaseModel):
    """Country where the name applies.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept country: Country code for where this name applies
    :param CodeableConcept jurisdiction: Jurisdiction code for where this name applies
    :param CodeableConcept language: Language code for this name
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "country": {"class_name": "CodeableConcept", "is_contained": False},
        "jurisdiction": {"class_name": "CodeableConcept", "is_contained": False},
        "language": {"class_name": "CodeableConcept", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        country: "CodeableConcept" = None,
        jurisdiction: "CodeableConcept" = None,
        language: "CodeableConcept" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.country = country
        self.jurisdiction = jurisdiction
        self.language = language

    @classmethod
    def from_dict(cls, data: dict) -> "MedicinalProduct":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "MedicinalProduct":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Name(FhirBaseModel):
    """The product's name, including full name and possibly coded parts.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str productName: The full product name
    :param NamePart namePart: Coding words or phrases of the name
    :param CountryLanguage countryLanguage: Country where the name applies
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "namePart": {"class_name": "NamePart", "is_contained": True},
        "countryLanguage": {"class_name": "CountryLanguage", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        productName: "str" = None,
        namePart: list["NamePart"] = None,
        countryLanguage: list["CountryLanguage"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.productName = productName
        self.namePart = namePart or []
        self.countryLanguage = countryLanguage or []

    @classmethod
    def from_dict(cls, data: dict) -> "MedicinalProduct":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "MedicinalProduct":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class ManufacturingBusinessOperation(FhirBaseModel):
    """An operation applied to the product, for manufacturing or adminsitrative purpose.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept operationType: The type of manufacturing operation
    :param Identifier authorisationReferenceNumber: Regulatory authorization reference number
    :param str effectiveDate: Regulatory authorization date
    :param CodeableConcept confidentialityIndicator: To indicate if this proces is commercially confidential
    :param Reference manufacturer: The manufacturer or establishment associated with the process
    :param Reference regulator: A regulator which oversees the operation
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "operationType": {"class_name": "CodeableConcept", "is_contained": False},
        "authorisationReferenceNumber": {
            "class_name": "Identifier",
            "is_contained": False,
        },
        "confidentialityIndicator": {
            "class_name": "CodeableConcept",
            "is_contained": False,
        },
        "manufacturer": {"class_name": "Reference", "is_contained": False},
        "regulator": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        operationType: "CodeableConcept" = None,
        authorisationReferenceNumber: "Identifier" = None,
        effectiveDate: "str" = None,
        confidentialityIndicator: "CodeableConcept" = None,
        manufacturer: list["Reference"] = None,
        regulator: "Reference" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.operationType = operationType
        self.authorisationReferenceNumber = authorisationReferenceNumber
        self.effectiveDate = effectiveDate
        self.confidentialityIndicator = confidentialityIndicator
        self.manufacturer = manufacturer or []
        self.regulator = regulator

    @classmethod
    def from_dict(cls, data: dict) -> "MedicinalProduct":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "MedicinalProduct":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class SpecialDesignation(FhirBaseModel):
    """Indicates if the medicinal product has an orphan designation for the treatment of a rare disease.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param Identifier identifier: Identifier for the designation, or procedure number
    :param CodeableConcept type: The type of special designation, e.g. orphan drug, minor use
    :param CodeableConcept intendedUse: The intended use of the product, e.g. prevention, treatment
    :param CodeableConcept indicationCodeableConcept: Condition for which the medicinal use applies
    :param Reference indicationReference: Condition for which the medicinal use applies
    :param CodeableConcept status: For example granted, pending, expired or withdrawn
    :param str date: Date when the designation was granted
    :param CodeableConcept species: Animal species for which this applies
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "intendedUse": {"class_name": "CodeableConcept", "is_contained": False},
        "indicationCodeableConcept": {
            "class_name": "CodeableConcept",
            "is_contained": False,
        },
        "indicationReference": {"class_name": "Reference", "is_contained": False},
        "status": {"class_name": "CodeableConcept", "is_contained": False},
        "species": {"class_name": "CodeableConcept", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        identifier: list["Identifier"] = None,
        type: "CodeableConcept" = None,
        intendedUse: "CodeableConcept" = None,
        indicationCodeableConcept: "CodeableConcept" = None,
        indicationReference: "Reference" = None,
        status: "CodeableConcept" = None,
        date: "str" = None,
        species: "CodeableConcept" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.identifier = identifier or []
        self.type = type
        self.intendedUse = intendedUse
        self.indicationCodeableConcept = indicationCodeableConcept
        self.indicationReference = indicationReference
        self.status = status
        self.date = date
        self.species = species

    @classmethod
    def from_dict(cls, data: dict) -> "MedicinalProduct":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "MedicinalProduct":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class MedicinalProduct(DomainResource):
    """Detailed definition of a medicinal product, typically for uses other than direct patient care (e.g. regulatory use).
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param Identifier identifier: Business identifier for this product. Could be an MPID
    :param CodeableConcept type: Regulatory type, e.g. Investigational or Authorized
    :param Coding domain: If this medicine applies to human or veterinary uses
    :param CodeableConcept combinedPharmaceuticalDoseForm: The dose form for a single part product, or combined form of a multiple part product
    :param CodeableConcept legalStatusOfSupply: The legal status of supply of the medicinal product as classified by the regulator
    :param CodeableConcept additionalMonitoringIndicator: Whether the Medicinal Product is subject to additional monitoring for regulatory reasons
    :param str specialMeasures: Whether the Medicinal Product is subject to special measures for regulatory reasons
    :param CodeableConcept paediatricUseIndicator: If authorised for use in children
    :param CodeableConcept productClassification: Allows the product to be classified by various systems
    :param MarketingStatus marketingStatus: Marketing status of the medicinal product, in contrast to marketing authorizaton
    :param Reference pharmaceuticalProduct: Pharmaceutical aspects of product
    :param Reference packagedMedicinalProduct: Package representation for the product
    :param Reference attachedDocument: Supporting documentation, typically for regulatory submission
    :param Reference masterFile: A master file for to the medicinal product (e.g. Pharmacovigilance System Master File)
    :param Reference contact: A product specific contact, person (in a role), or an organization
    :param Reference clinicalTrial: Clinical trials or studies that this product is involved in
    :param Name name: The product's name, including full name and possibly coded parts
    :param Identifier crossReference: Reference to another product, e.g. for linking authorised to investigational product
    :param ManufacturingBusinessOperation manufacturingBusinessOperation: An operation applied to the product, for manufacturing or adminsitrative purpose
    :param SpecialDesignation specialDesignation: Indicates if the medicinal product has an orphan designation for the treatment of a rare disease
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "domain": {"class_name": "Coding", "is_contained": False},
        "combinedPharmaceuticalDoseForm": {
            "class_name": "CodeableConcept",
            "is_contained": False,
        },
        "legalStatusOfSupply": {"class_name": "CodeableConcept", "is_contained": False},
        "additionalMonitoringIndicator": {
            "class_name": "CodeableConcept",
            "is_contained": False,
        },
        "paediatricUseIndicator": {
            "class_name": "CodeableConcept",
            "is_contained": False,
        },
        "productClassification": {
            "class_name": "CodeableConcept",
            "is_contained": False,
        },
        "marketingStatus": {"class_name": "MarketingStatus", "is_contained": False},
        "pharmaceuticalProduct": {"class_name": "Reference", "is_contained": False},
        "packagedMedicinalProduct": {"class_name": "Reference", "is_contained": False},
        "attachedDocument": {"class_name": "Reference", "is_contained": False},
        "masterFile": {"class_name": "Reference", "is_contained": False},
        "contact": {"class_name": "Reference", "is_contained": False},
        "clinicalTrial": {"class_name": "Reference", "is_contained": False},
        "name": {"class_name": "Name", "is_contained": True},
        "crossReference": {"class_name": "Identifier", "is_contained": False},
        "manufacturingBusinessOperation": {
            "class_name": "ManufacturingBusinessOperation",
            "is_contained": True,
        },
        "specialDesignation": {
            "class_name": "SpecialDesignation",
            "is_contained": True,
        },
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        identifier: list["Identifier"] = None,
        type: "CodeableConcept" = None,
        domain: "Coding" = None,
        combinedPharmaceuticalDoseForm: "CodeableConcept" = None,
        legalStatusOfSupply: "CodeableConcept" = None,
        additionalMonitoringIndicator: "CodeableConcept" = None,
        specialMeasures: list["str"] = None,
        paediatricUseIndicator: "CodeableConcept" = None,
        productClassification: list["CodeableConcept"] = None,
        marketingStatus: list["MarketingStatus"] = None,
        pharmaceuticalProduct: list["Reference"] = None,
        packagedMedicinalProduct: list["Reference"] = None,
        attachedDocument: list["Reference"] = None,
        masterFile: list["Reference"] = None,
        contact: list["Reference"] = None,
        clinicalTrial: list["Reference"] = None,
        name: list["Name"] = None,
        crossReference: list["Identifier"] = None,
        manufacturingBusinessOperation: list["ManufacturingBusinessOperation"] = None,
        specialDesignation: list["SpecialDesignation"] = None,
    ):

        self.resourceType = "MedicinalProduct"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.identifier = identifier or []
        self.type = type
        self.domain = domain
        self.combinedPharmaceuticalDoseForm = combinedPharmaceuticalDoseForm
        self.legalStatusOfSupply = legalStatusOfSupply
        self.additionalMonitoringIndicator = additionalMonitoringIndicator
        self.specialMeasures = specialMeasures or []
        self.paediatricUseIndicator = paediatricUseIndicator
        self.productClassification = productClassification or []
        self.marketingStatus = marketingStatus or []
        self.pharmaceuticalProduct = pharmaceuticalProduct or []
        self.packagedMedicinalProduct = packagedMedicinalProduct or []
        self.attachedDocument = attachedDocument or []
        self.masterFile = masterFile or []
        self.contact = contact or []
        self.clinicalTrial = clinicalTrial or []
        self.name = name or []
        self.crossReference = crossReference or []
        self.manufacturingBusinessOperation = manufacturingBusinessOperation or []
        self.specialDesignation = specialDesignation or []

    @classmethod
    def from_dict(cls, data: dict) -> "MedicinalProduct":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "MedicinalProduct":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for ParameterDefinition. 
Time: 2024-06-14 18:37:49
"""

from fhirmodels.generator import FhirBaseModel
from fhirmodels.R4B.Extension import *


class ParameterDefinition(FhirBaseModel):
    """Base StructureDefinition for ParameterDefinition Type: The parameters to the module. This collection specifies both the input and output parameters. Input parameters are provided by the caller as part of the $evaluate operation. Output parameters are included in the GuidanceResponse.
    :param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param str name: Name used to access the parameter value
    :param str use: in | out
    :param int min: Minimum cardinality
    :param str max: Maximum cardinality (a number of *)
    :param str documentation: A brief description of the parameter
    :param str type: What type of value
    :param str profile: What profile the value is expected to be
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        name: "str" = None,
        use: "str" = None,
        min: "int" = None,
        max: "str" = None,
        documentation: "str" = None,
        type: "str" = None,
        profile: "str" = None,
    ):

        self.id = id
        self.extension = extension or []
        self.name = name
        self.use = use
        self.min = min
        self.max = max
        self.documentation = documentation
        self.type = type
        self.profile = profile

    @classmethod
    def from_dict(cls, data: dict) -> "ParameterDefinition":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ParameterDefinition":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for Attachment. 
Time: 2024-06-14 18:37:55
"""

from fhirmodels.generator import FhirBaseModel
from fhirmodels.R5.Extension import *


class Attachment(FhirBaseModel):
    """Attachment Type: For referring to data content defined in other formats.
    :param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param str contentType: Mime type of the content, with charset etc.
    :param str language: Human language of the content (BCP-47)
    :param str data: Data inline, base64ed
    :param str url: Uri where the data can be found
    :param int size: Number of bytes of content (if url provided)
    :param str hash: Hash of the data (sha-1, base64ed)
    :param str title: Label to display in place of the data
    :param str creation: Date attachment was first created
    :param int height: Height of the image in pixels (photo/video)
    :param int width: Width of the image in pixels (photo/video)
    :param int frames: Number of frames if > 1 (photo)
    :param float duration: Length in seconds (audio / video)
    :param int pages: Number of printed pages
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        contentType: "str" = None,
        language: "str" = None,
        data: "str" = None,
        url: "str" = None,
        size: "int" = None,
        hash: "str" = None,
        title: "str" = None,
        creation: "str" = None,
        height: "int" = None,
        width: "int" = None,
        frames: "int" = None,
        duration: "float" = None,
        pages: "int" = None,
    ):

        self.id = id
        self.extension = extension or []
        self.contentType = contentType
        self.language = language
        self.data = data
        self.url = url
        self.size = size
        self.hash = hash
        self.title = title
        self.creation = creation
        self.height = height
        self.width = width
        self.frames = frames
        self.duration = duration
        self.pages = pages

    @classmethod
    def from_dict(cls, data: dict) -> "Attachment":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Attachment":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for DataRequirement. 
Time: 2024-06-14 18:37:55
"""

from fhirmodels.generator import FhirBaseModel
from fhirmodels.R5.CodeableConcept import *
from fhirmodels.R5.Coding import *
from fhirmodels.R5.Duration import *
from fhirmodels.R5.Element import *
from fhirmodels.R5.Extension import *
from fhirmodels.R5.Period import *
from fhirmodels.R5.Reference import *


class CodeFilter(FhirBaseModel):
    """Code filters specify additional constraints on the data, specifying the value set of interest for a particular element of the data. Each code filter defines an additional constraint on the data, i.e. code filters are AND'ed, not OR'ed.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param str path: A code-valued attribute to filter on
    :param str searchParam: A coded (token) parameter to search on
    :param str valueSet: ValueSet for the filter
    :param Coding code: What code is expected
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "code": {"class_name": "Coding", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        path: "str" = None,
        searchParam: "str" = None,
        valueSet: "str" = None,
        code: list["Coding"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.path = path
        self.searchParam = searchParam
        self.valueSet = valueSet
        self.code = code or []

    @classmethod
    def from_dict(cls, data: dict) -> "DataRequirement":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "DataRequirement":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class DateFilter(FhirBaseModel):
    """Date filters specify additional constraints on the data in terms of the applicable date range for specific elements. Each date filter specifies an additional constraint on the data, i.e. date filters are AND'ed, not OR'ed.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param str path: A date-valued attribute to filter on
    :param str searchParam: A date valued parameter to search on
    :param str valueDateTime: The value of the filter, as a Period, DateTime, or Duration value
    :param Period valuePeriod: The value of the filter, as a Period, DateTime, or Duration value
    :param Duration valueDuration: The value of the filter, as a Period, DateTime, or Duration value
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "valuePeriod": {"class_name": "Period", "is_contained": False},
        "valueDuration": {"class_name": "Duration", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        path: "str" = None,
        searchParam: "str" = None,
        valueDateTime: "str" = None,
        valuePeriod: "Period" = None,
        valueDuration: "Duration" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.path = path
        self.searchParam = searchParam
        self.valueDateTime = valueDateTime
        self.valuePeriod = valuePeriod
        self.valueDuration = valueDuration

    @classmethod
    def from_dict(cls, data: dict) -> "DataRequirement":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "DataRequirement":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class ValueFilter(FhirBaseModel):
    """Value filters specify additional constraints on the data for elements other than code-valued or date-valued. Each value filter specifies an additional constraint on the data (i.e. valueFilters are AND'ed, not OR'ed).:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param str path: An attribute to filter on
    :param str searchParam: A parameter to search on
    :param str comparator: eq | gt | lt | ge | le | sa | eb
    :param str valueDateTime: The value of the filter, as a Period, DateTime, or Duration value
    :param Period valuePeriod: The value of the filter, as a Period, DateTime, or Duration value
    :param Duration valueDuration: The value of the filter, as a Period, DateTime, or Duration value
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "valuePeriod": {"class_name": "Period", "is_contained": False},
        "valueDuration": {"class_name": "Duration", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        path: "str" = None,
        searchParam: "str" = None,
        comparator: "str" = None,
        valueDateTime: "str" = None,
        valuePeriod: "Period" = None,
        valueDuration: "Duration" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.path = path
        self.searchParam = searchParam
        self.comparator = comparator
        self.valueDateTime = valueDateTime
        self.valuePeriod = valuePeriod
        self.valueDuration = valueDuration

    @classmethod
    def from_dict(cls, data: dict) -> "DataRequirement":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "DataRequirement":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Sort(FhirBaseModel):
    """Specifies the order of the results to be returned.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param str path: The name of the attribute to perform the sort
    :param str direction: ascending | descending
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        path: "str" = None,
        direction: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.path = path
        self.direction = direction

    @classmethod
    def from_dict(cls, data: dict) -> "DataRequirement":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "DataRequirement":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class DataRequirement(FhirBaseModel):
    """DataRequirement Type: Describes a required data item for evaluation in terms of the type of data, and optional code or date-based filters of the data.
    :param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param str type: The type of the required data
    :param str profile: The profile of the required data
    :param CodeableConcept subjectCodeableConcept: E.g. Patient, Practitioner, RelatedPerson, Organization, Location, Device
    :param Reference subjectReference: E.g. Patient, Practitioner, RelatedPerson, Organization, Location, Device
    :param str mustSupport: Indicates specific structure elements that are referenced by the knowledge module
    :param CodeFilter codeFilter: What codes are expected
    :param DateFilter dateFilter: What dates/date ranges are expected
    :param ValueFilter valueFilter: What values are expected
    :param int limit: Number of results
    :param Sort sort: Order of the results
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "subjectCodeableConcept": {
            "class_name": "CodeableConcept",
            "is_contained": False,
        },
        "subjectReference": {"class_name": "Reference", "is_contained": False},
        "codeFilter": {"class_name": "CodeFilter", "is_contained": True},
        "dateFilter": {"class_name": "DateFilter", "is_contained": True},
        "valueFilter": {"class_name": "ValueFilter", "is_contained": True},
        "sort": {"class_name": "Sort", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        type: "str" = None,
        profile: list["str"] = None,
        subjectCodeableConcept: "CodeableConcept" = None,
        subjectReference: "Reference" = None,
        mustSupport: list["str"] = None,
        codeFilter: list["CodeFilter"] = None,
        dateFilter: list["DateFilter"] = None,
        valueFilter: list["ValueFilter"] = None,
        limit: "int" = None,
        sort: list["Sort"] = None,
    ):

        self.id = id
        self.extension = extension or []
        self.type = type
        self.profile = profile or []
        self.subjectCodeableConcept = subjectCodeableConcept
        self.subjectReference = subjectReference
        self.mustSupport = mustSupport or []
        self.codeFilter = codeFilter or []
        self.dateFilter = dateFilter or []
        self.valueFilter = valueFilter or []
        self.limit = limit
        self.sort = sort or []

    @classmethod
    def from_dict(cls, data: dict) -> "DataRequirement":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "DataRequirement":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for MonetaryComponent. 
Time: 2024-06-14 18:37:55
"""

from fhirmodels.generator import FhirBaseModel
from fhirmodels.R5.CodeableConcept import *
from fhirmodels.R5.Extension import *
from fhirmodels.R5.Money import *


class MonetaryComponent(FhirBaseModel):
    """MonetaryComponent Type: Availability data for an {item}.
    :param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param str type: base | surcharge | deduction | discount | tax | informational
    :param CodeableConcept code: Codes may be used to differentiate between kinds of taxes, surcharges, discounts etc.
    :param float factor: Factor used for calculating this component
    :param Money amount: Explicit value amount to be used
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "code": {"class_name": "CodeableConcept", "is_contained": False},
        "amount": {"class_name": "Money", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        type: "str" = None,
        code: "CodeableConcept" = None,
        factor: "float" = None,
        amount: "Money" = None,
    ):

        self.id = id
        self.extension = extension or []
        self.type = type
        self.code = code
        self.factor = factor
        self.amount = amount

    @classmethod
    def from_dict(cls, data: dict) -> "MonetaryComponent":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "MonetaryComponent":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for CodeableReference. 
Time: 2024-06-14 18:37:49
"""

from fhirmodels.generator import FhirBaseModel
from fhirmodels.R4B.CodeableConcept import *
from fhirmodels.R4B.Extension import *
from fhirmodels.R4B.Reference import *


class CodeableReference(FhirBaseModel):
    """Base StructureDefinition for CodeableReference Type: A reference to a resource (by instance), or instead, a reference to a concept defined in a terminology or ontology (by class).
    :param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param CodeableConcept concept: Reference to a concept (by class)
    :param Reference reference: Reference to a resource (by instance)
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "concept": {"class_name": "CodeableConcept", "is_contained": False},
        "reference": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        concept: "CodeableConcept" = None,
        reference: "Reference" = None,
    ):

        self.id = id
        self.extension = extension or []
        self.concept = concept
        self.reference = reference

    @classmethod
    def from_dict(cls, data: dict) -> "CodeableReference":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "CodeableReference":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for DeviceAssociation. 
Time: 2024-06-14 18:37:55
"""

from fhirmodels.R5.BackboneElement import *
from fhirmodels.R5.CodeableConcept import *
from fhirmodels.R5.DomainResource import *
from fhirmodels.R5.Extension import *
from fhirmodels.R5.Identifier import *
from fhirmodels.R5.Meta import *
from fhirmodels.R5.Narrative import *
from fhirmodels.R5.Period import *
from fhirmodels.R5.Reference import *
from fhirmodels.R5.Resource import *


class Operation(FhirBaseModel):
    """The details about the device when it is in use to describe its operation.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept status: Device operational condition
    :param Reference operator: The individual performing the action enabled by the device
    :param Period period: Begin and end dates and times for the device's operation
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "status": {"class_name": "CodeableConcept", "is_contained": False},
        "operator": {"class_name": "Reference", "is_contained": False},
        "period": {"class_name": "Period", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        status: "CodeableConcept" = None,
        operator: list["Reference"] = None,
        period: "Period" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.status = status
        self.operator = operator or []
        self.period = period

    @classmethod
    def from_dict(cls, data: dict) -> "DeviceAssociation":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "DeviceAssociation":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class DeviceAssociation(DomainResource):
    """A record of association of a device.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param Identifier identifier: Instance identifier
    :param Reference device: Reference to the devices associated with the patient or group
    :param CodeableConcept category: Describes the relationship between the device and subject
    :param CodeableConcept status: implanted | explanted | attached | entered-in-error | unknown
    :param CodeableConcept statusReason: The reasons given for the current association status
    :param Reference subject: The individual, group of individuals or device that the device is on or associated with
    :param Reference bodyStructure: Current anatomical location of the device in/on subject
    :param Period period: Begin and end dates and times for the device association
    :param Operation operation: The details about the device when it is in use to describe its operation
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "device": {"class_name": "Reference", "is_contained": False},
        "category": {"class_name": "CodeableConcept", "is_contained": False},
        "status": {"class_name": "CodeableConcept", "is_contained": False},
        "statusReason": {"class_name": "CodeableConcept", "is_contained": False},
        "subject": {"class_name": "Reference", "is_contained": False},
        "bodyStructure": {"class_name": "Reference", "is_contained": False},
        "period": {"class_name": "Period", "is_contained": False},
        "operation": {"class_name": "Operation", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        identifier: list["Identifier"] = None,
        device: "Reference" = None,
        category: list["CodeableConcept"] = None,
        status: "CodeableConcept" = None,
        statusReason: list["CodeableConcept"] = None,
        subject: "Reference" = None,
        bodyStructure: "Reference" = None,
        period: "Period" = None,
        operation: list["Operation"] = None,
    ):

        self.resourceType = "DeviceAssociation"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.identifier = identifier or []
        self.device = device
        self.category = category or []
        self.status = status
        self.statusReason = statusReason or []
        self.subject = subject
        self.bodyStructure = bodyStructure
        self.period = period
        self.operation = operation or []

    @classmethod
    def from_dict(cls, data: dict) -> "DeviceAssociation":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "DeviceAssociation":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for ExplanationOfBenefit. 
Time: 2024-06-14 18:37:49
"""

from fhirmodels.R4B.Address import *
from fhirmodels.R4B.Attachment import *
from fhirmodels.R4B.BackboneElement import *
from fhirmodels.R4B.CodeableConcept import *
from fhirmodels.R4B.Coding import *
from fhirmodels.R4B.DomainResource import *
from fhirmodels.R4B.Extension import *
from fhirmodels.R4B.Identifier import *
from fhirmodels.R4B.Meta import *
from fhirmodels.R4B.Money import *
from fhirmodels.R4B.Narrative import *
from fhirmodels.R4B.Period import *
from fhirmodels.R4B.Quantity import *
from fhirmodels.R4B.Reference import *
from fhirmodels.R4B.Resource import *


class Related(FhirBaseModel):
    """Other claims which are related to this claim such as prior submissions or claims for related services or for the same event.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param Reference claim: Reference to the related claim
    :param CodeableConcept relationship: How the reference claim is related
    :param Identifier reference: File or case reference
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "claim": {"class_name": "Reference", "is_contained": False},
        "relationship": {"class_name": "CodeableConcept", "is_contained": False},
        "reference": {"class_name": "Identifier", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        claim: "Reference" = None,
        relationship: "CodeableConcept" = None,
        reference: "Identifier" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.claim = claim
        self.relationship = relationship
        self.reference = reference

    @classmethod
    def from_dict(cls, data: dict) -> "ExplanationOfBenefit":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ExplanationOfBenefit":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Payee(FhirBaseModel):
    """The party to be reimbursed for cost of the products and services according to the terms of the policy.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept type: Category of recipient
    :param Reference party: Recipient reference
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "party": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        type: "CodeableConcept" = None,
        party: "Reference" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.type = type
        self.party = party

    @classmethod
    def from_dict(cls, data: dict) -> "ExplanationOfBenefit":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ExplanationOfBenefit":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class CareTeam(FhirBaseModel):
    """The members of the team who provided the products and services.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param int sequence: Order of care team
    :param Reference provider: Practitioner or organization
    :param bool responsible: Indicator of the lead practitioner
    :param CodeableConcept role: Function within the team
    :param CodeableConcept qualification: Practitioner credential or specialization
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "provider": {"class_name": "Reference", "is_contained": False},
        "role": {"class_name": "CodeableConcept", "is_contained": False},
        "qualification": {"class_name": "CodeableConcept", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        sequence: "int" = None,
        provider: "Reference" = None,
        responsible: "bool" = None,
        role: "CodeableConcept" = None,
        qualification: "CodeableConcept" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.sequence = sequence
        self.provider = provider
        self.responsible = responsible
        self.role = role
        self.qualification = qualification

    @classmethod
    def from_dict(cls, data: dict) -> "ExplanationOfBenefit":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ExplanationOfBenefit":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class SupportingInfo(FhirBaseModel):
    """Additional information codes regarding exceptions, special considerations, the condition, situation, prior or concurrent issues.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param int sequence: Information instance identifier
    :param CodeableConcept category: Classification of the supplied information
    :param CodeableConcept code: Type of information
    :param str timingDate: When it occurred
    :param Period timingPeriod: When it occurred
    :param bool valueBoolean: Data to be provided
    :param str valueString: Data to be provided
    :param Quantity valueQuantity: Data to be provided
    :param Attachment valueAttachment: Data to be provided
    :param Reference valueReference: Data to be provided
    :param Coding reason: Explanation for the information
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "category": {"class_name": "CodeableConcept", "is_contained": False},
        "code": {"class_name": "CodeableConcept", "is_contained": False},
        "timingPeriod": {"class_name": "Period", "is_contained": False},
        "valueQuantity": {"class_name": "Quantity", "is_contained": False},
        "valueAttachment": {"class_name": "Attachment", "is_contained": False},
        "valueReference": {"class_name": "Reference", "is_contained": False},
        "reason": {"class_name": "Coding", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        sequence: "int" = None,
        category: "CodeableConcept" = None,
        code: "CodeableConcept" = None,
        timingDate: "str" = None,
        timingPeriod: "Period" = None,
        valueBoolean: "bool" = None,
        valueString: "str" = None,
        valueQuantity: "Quantity" = None,
        valueAttachment: "Attachment" = None,
        valueReference: "Reference" = None,
        reason: "Coding" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.sequence = sequence
        self.category = category
        self.code = code
        self.timingDate = timingDate
        self.timingPeriod = timingPeriod
        self.valueBoolean = valueBoolean
        self.valueString = valueString
        self.valueQuantity = valueQuantity
        self.valueAttachment = valueAttachment
        self.valueReference = valueReference
        self.reason = reason

    @classmethod
    def from_dict(cls, data: dict) -> "ExplanationOfBenefit":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ExplanationOfBenefit":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Diagnosis(FhirBaseModel):
    """Information about diagnoses relevant to the claim items.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param int sequence: Diagnosis instance identifier
    :param CodeableConcept diagnosisCodeableConcept: Nature of illness or problem
    :param Reference diagnosisReference: Nature of illness or problem
    :param CodeableConcept type: Timing or nature of the diagnosis
    :param CodeableConcept onAdmission: Present on admission
    :param CodeableConcept packageCode: Package billing code
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "diagnosisCodeableConcept": {
            "class_name": "CodeableConcept",
            "is_contained": False,
        },
        "diagnosisReference": {"class_name": "Reference", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "onAdmission": {"class_name": "CodeableConcept", "is_contained": False},
        "packageCode": {"class_name": "CodeableConcept", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        sequence: "int" = None,
        diagnosisCodeableConcept: "CodeableConcept" = None,
        diagnosisReference: "Reference" = None,
        type: list["CodeableConcept"] = None,
        onAdmission: "CodeableConcept" = None,
        packageCode: "CodeableConcept" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.sequence = sequence
        self.diagnosisCodeableConcept = diagnosisCodeableConcept
        self.diagnosisReference = diagnosisReference
        self.type = type or []
        self.onAdmission = onAdmission
        self.packageCode = packageCode

    @classmethod
    def from_dict(cls, data: dict) -> "ExplanationOfBenefit":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ExplanationOfBenefit":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Procedure(FhirBaseModel):
    """Procedures performed on the patient relevant to the billing items with the claim.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param int sequence: Procedure instance identifier
    :param CodeableConcept type: Category of Procedure
    :param str date: When the procedure was performed
    :param CodeableConcept procedureCodeableConcept: Specific clinical procedure
    :param Reference procedureReference: Specific clinical procedure
    :param Reference udi: Unique device identifier
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "procedureCodeableConcept": {
            "class_name": "CodeableConcept",
            "is_contained": False,
        },
        "procedureReference": {"class_name": "Reference", "is_contained": False},
        "udi": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        sequence: "int" = None,
        type: list["CodeableConcept"] = None,
        date: "str" = None,
        procedureCodeableConcept: "CodeableConcept" = None,
        procedureReference: "Reference" = None,
        udi: list["Reference"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.sequence = sequence
        self.type = type or []
        self.date = date
        self.procedureCodeableConcept = procedureCodeableConcept
        self.procedureReference = procedureReference
        self.udi = udi or []

    @classmethod
    def from_dict(cls, data: dict) -> "ExplanationOfBenefit":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ExplanationOfBenefit":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Insurance(FhirBaseModel):
    """Financial instruments for reimbursement for the health care products and services specified on the claim.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param bool focal: Coverage to be used for adjudication
    :param Reference coverage: Insurance information
    :param str preAuthRef: Prior authorization reference number
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "coverage": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        focal: "bool" = None,
        coverage: "Reference" = None,
        preAuthRef: list["str"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.focal = focal
        self.coverage = coverage
        self.preAuthRef = preAuthRef or []

    @classmethod
    def from_dict(cls, data: dict) -> "ExplanationOfBenefit":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ExplanationOfBenefit":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Accident(FhirBaseModel):
    """Details of a accident which resulted in injuries which required the products and services listed in the claim.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str date: When the incident occurred
    :param CodeableConcept type: The nature of the accident
    :param Address locationAddress: Where the event occurred
    :param Reference locationReference: Where the event occurred
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "locationAddress": {"class_name": "Address", "is_contained": False},
        "locationReference": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        date: "str" = None,
        type: "CodeableConcept" = None,
        locationAddress: "Address" = None,
        locationReference: "Reference" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.date = date
        self.type = type
        self.locationAddress = locationAddress
        self.locationReference = locationReference

    @classmethod
    def from_dict(cls, data: dict) -> "ExplanationOfBenefit":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ExplanationOfBenefit":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Adjudication(FhirBaseModel):
    """If this item is a group then the values here are a summary of the adjudication of the detail items. If this item is a simple product or service then this is the result of the adjudication of this item.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept category: Type of adjudication information
    :param CodeableConcept reason: Explanation of adjudication outcome
    :param Money amount: Monetary amount
    :param float value: Non-monitary value
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "category": {"class_name": "CodeableConcept", "is_contained": False},
        "reason": {"class_name": "CodeableConcept", "is_contained": False},
        "amount": {"class_name": "Money", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        category: "CodeableConcept" = None,
        reason: "CodeableConcept" = None,
        amount: "Money" = None,
        value: "float" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.category = category
        self.reason = reason
        self.amount = amount
        self.value = value

    @classmethod
    def from_dict(cls, data: dict) -> "ExplanationOfBenefit":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ExplanationOfBenefit":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class SubDetail(FhirBaseModel):
    """Third-tier of goods and services.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param int sequence: Product or service provided
    :param CodeableConcept revenue: Revenue or cost center code
    :param CodeableConcept category: Benefit classification
    :param CodeableConcept productOrService: Billing, service, product, or drug code
    :param CodeableConcept modifier: Service/Product billing modifiers
    :param CodeableConcept programCode: Program the product or service is provided under
    :param Quantity quantity: Count of products or services
    :param Money unitPrice: Fee, charge or cost per item
    :param float factor: Price scaling factor
    :param Money net: Total item cost
    :param Reference udi: Unique device identifier
    :param int noteNumber: Applicable note numbers
    :param Adjudication adjudication: Subdetail level adjudication details
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "revenue": {"class_name": "CodeableConcept", "is_contained": False},
        "category": {"class_name": "CodeableConcept", "is_contained": False},
        "productOrService": {"class_name": "CodeableConcept", "is_contained": False},
        "modifier": {"class_name": "CodeableConcept", "is_contained": False},
        "programCode": {"class_name": "CodeableConcept", "is_contained": False},
        "quantity": {"class_name": "Quantity", "is_contained": False},
        "unitPrice": {"class_name": "Money", "is_contained": False},
        "net": {"class_name": "Money", "is_contained": False},
        "udi": {"class_name": "Reference", "is_contained": False},
        "adjudication": {"class_name": "Adjudication", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        sequence: "int" = None,
        revenue: "CodeableConcept" = None,
        category: "CodeableConcept" = None,
        productOrService: "CodeableConcept" = None,
        modifier: list["CodeableConcept"] = None,
        programCode: list["CodeableConcept"] = None,
        quantity: "Quantity" = None,
        unitPrice: "Money" = None,
        factor: "float" = None,
        net: "Money" = None,
        udi: list["Reference"] = None,
        noteNumber: list["int"] = None,
        adjudication: list["Adjudication"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.sequence = sequence
        self.revenue = revenue
        self.category = category
        self.productOrService = productOrService
        self.modifier = modifier or []
        self.programCode = programCode or []
        self.quantity = quantity
        self.unitPrice = unitPrice
        self.factor = factor
        self.net = net
        self.udi = udi or []
        self.noteNumber = noteNumber or []
        self.adjudication = adjudication or []

    @classmethod
    def from_dict(cls, data: dict) -> "ExplanationOfBenefit":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ExplanationOfBenefit":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Detail(FhirBaseModel):
    """Second-tier of goods and services.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param int sequence: Product or service provided
    :param CodeableConcept revenue: Revenue or cost center code
    :param CodeableConcept category: Benefit classification
    :param CodeableConcept productOrService: Billing, service, product, or drug code
    :param CodeableConcept modifier: Service/Product billing modifiers
    :param CodeableConcept programCode: Program the product or service is provided under
    :param Quantity quantity: Count of products or services
    :param Money unitPrice: Fee, charge or cost per item
    :param float factor: Price scaling factor
    :param Money net: Total item cost
    :param Reference udi: Unique device identifier
    :param int noteNumber: Applicable note numbers
    :param Adjudication adjudication: Detail level adjudication details
    :param SubDetail subDetail: Additional items
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "revenue": {"class_name": "CodeableConcept", "is_contained": False},
        "category": {"class_name": "CodeableConcept", "is_contained": False},
        "productOrService": {"class_name": "CodeableConcept", "is_contained": False},
        "modifier": {"class_name": "CodeableConcept", "is_contained": False},
        "programCode": {"class_name": "CodeableConcept", "is_contained": False},
        "quantity": {"class_name": "Quantity", "is_contained": False},
        "unitPrice": {"class_name": "Money", "is_contained": False},
        "net": {"class_name": "Money", "is_contained": False},
        "udi": {"class_name": "Reference", "is_contained": False},
        "adjudication": {"class_name": "Adjudication", "is_contained": True},
        "subDetail": {"class_name": "SubDetail", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        sequence: "int" = None,
        revenue: "CodeableConcept" = None,
        category: "CodeableConcept" = None,
        productOrService: "CodeableConcept" = None,
        modifier: list["CodeableConcept"] = None,
        programCode: list["CodeableConcept"] = None,
        quantity: "Quantity" = None,
        unitPrice: "Money" = None,
        factor: "float" = None,
        net: "Money" = None,
        udi: list["Reference"] = None,
        noteNumber: list["int"] = None,
        adjudication: list["Adjudication"] = None,
        subDetail: list["SubDetail"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.sequence = sequence
        self.revenue = revenue
        self.category = category
        self.productOrService = productOrService
        self.modifier = modifier or []
        self.programCode = programCode or []
        self.quantity = quantity
        self.unitPrice = unitPrice
        self.factor = factor
        self.net = net
        self.udi = udi or []
        self.noteNumber = noteNumber or []
        self.adjudication = adjudication or []
        self.subDetail = subDetail or []

    @classmethod
    def from_dict(cls, data: dict) -> "ExplanationOfBenefit":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ExplanationOfBenefit":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Item(FhirBaseModel):
    """A claim line. Either a simple (a product or service) or a 'group' of details which can also be a simple items or groups of sub-details.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param int sequence: Item instance identifier
    :param int careTeamSequence: Applicable care team members
    :param int diagnosisSequence: Applicable diagnoses
    :param int procedureSequence: Applicable procedures
    :param int informationSequence: Applicable exception and supporting information
    :param CodeableConcept revenue: Revenue or cost center code
    :param CodeableConcept category: Benefit classification
    :param CodeableConcept productOrService: Billing, service, product, or drug code
    :param CodeableConcept modifier: Product or service billing modifiers
    :param CodeableConcept programCode: Program the product or service is provided under
    :param str servicedDate: Date or dates of service or product delivery
    :param Period servicedPeriod: Date or dates of service or product delivery
    :param CodeableConcept locationCodeableConcept: Place of service or where product was supplied
    :param Address locationAddress: Place of service or where product was supplied
    :param Reference locationReference: Place of service or where product was supplied
    :param Quantity quantity: Count of products or services
    :param Money unitPrice: Fee, charge or cost per item
    :param float factor: Price scaling factor
    :param Money net: Total item cost
    :param Reference udi: Unique device identifier
    :param CodeableConcept bodySite: Anatomical location
    :param CodeableConcept subSite: Anatomical sub-location
    :param Reference encounter: Encounters related to this billed item
    :param int noteNumber: Applicable note numbers
    :param Adjudication adjudication: Adjudication details
    :param Detail detail: Additional items
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "revenue": {"class_name": "CodeableConcept", "is_contained": False},
        "category": {"class_name": "CodeableConcept", "is_contained": False},
        "productOrService": {"class_name": "CodeableConcept", "is_contained": False},
        "modifier": {"class_name": "CodeableConcept", "is_contained": False},
        "programCode": {"class_name": "CodeableConcept", "is_contained": False},
        "servicedPeriod": {"class_name": "Period", "is_contained": False},
        "locationCodeableConcept": {
            "class_name": "CodeableConcept",
            "is_contained": False,
        },
        "locationAddress": {"class_name": "Address", "is_contained": False},
        "locationReference": {"class_name": "Reference", "is_contained": False},
        "quantity": {"class_name": "Quantity", "is_contained": False},
        "unitPrice": {"class_name": "Money", "is_contained": False},
        "net": {"class_name": "Money", "is_contained": False},
        "udi": {"class_name": "Reference", "is_contained": False},
        "bodySite": {"class_name": "CodeableConcept", "is_contained": False},
        "subSite": {"class_name": "CodeableConcept", "is_contained": False},
        "encounter": {"class_name": "Reference", "is_contained": False},
        "adjudication": {"class_name": "Adjudication", "is_contained": True},
        "detail": {"class_name": "Detail", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        sequence: "int" = None,
        careTeamSequence: list["int"] = None,
        diagnosisSequence: list["int"] = None,
        procedureSequence: list["int"] = None,
        informationSequence: list["int"] = None,
        revenue: "CodeableConcept" = None,
        category: "CodeableConcept" = None,
        productOrService: "CodeableConcept" = None,
        modifier: list["CodeableConcept"] = None,
        programCode: list["CodeableConcept"] = None,
        servicedDate: "str" = None,
        servicedPeriod: "Period" = None,
        locationCodeableConcept: "CodeableConcept" = None,
        locationAddress: "Address" = None,
        locationReference: "Reference" = None,
        quantity: "Quantity" = None,
        unitPrice: "Money" = None,
        factor: "float" = None,
        net: "Money" = None,
        udi: list["Reference"] = None,
        bodySite: "CodeableConcept" = None,
        subSite: list["CodeableConcept"] = None,
        encounter: list["Reference"] = None,
        noteNumber: list["int"] = None,
        adjudication: list["Adjudication"] = None,
        detail: list["Detail"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.sequence = sequence
        self.careTeamSequence = careTeamSequence or []
        self.diagnosisSequence = diagnosisSequence or []
        self.procedureSequence = procedureSequence or []
        self.informationSequence = informationSequence or []
        self.revenue = revenue
        self.category = category
        self.productOrService = productOrService
        self.modifier = modifier or []
        self.programCode = programCode or []
        self.servicedDate = servicedDate
        self.servicedPeriod = servicedPeriod
        self.locationCodeableConcept = locationCodeableConcept
        self.locationAddress = locationAddress
        self.locationReference = locationReference
        self.quantity = quantity
        self.unitPrice = unitPrice
        self.factor = factor
        self.net = net
        self.udi = udi or []
        self.bodySite = bodySite
        self.subSite = subSite or []
        self.encounter = encounter or []
        self.noteNumber = noteNumber or []
        self.adjudication = adjudication or []
        self.detail = detail or []

    @classmethod
    def from_dict(cls, data: dict) -> "ExplanationOfBenefit":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ExplanationOfBenefit":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class SubDetail(FhirBaseModel):
    """The third-tier service adjudications for payor added services.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept productOrService: Billing, service, product, or drug code
    :param CodeableConcept modifier: Service/Product billing modifiers
    :param Quantity quantity: Count of products or services
    :param Money unitPrice: Fee, charge or cost per item
    :param float factor: Price scaling factor
    :param Money net: Total item cost
    :param int noteNumber: Applicable note numbers
    :param Adjudication adjudication: Added items adjudication
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "productOrService": {"class_name": "CodeableConcept", "is_contained": False},
        "modifier": {"class_name": "CodeableConcept", "is_contained": False},
        "quantity": {"class_name": "Quantity", "is_contained": False},
        "unitPrice": {"class_name": "Money", "is_contained": False},
        "net": {"class_name": "Money", "is_contained": False},
        "adjudication": {"class_name": "Adjudication", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        productOrService: "CodeableConcept" = None,
        modifier: list["CodeableConcept"] = None,
        quantity: "Quantity" = None,
        unitPrice: "Money" = None,
        factor: "float" = None,
        net: "Money" = None,
        noteNumber: list["int"] = None,
        adjudication: list["Adjudication"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.productOrService = productOrService
        self.modifier = modifier or []
        self.quantity = quantity
        self.unitPrice = unitPrice
        self.factor = factor
        self.net = net
        self.noteNumber = noteNumber or []
        self.adjudication = adjudication or []

    @classmethod
    def from_dict(cls, data: dict) -> "ExplanationOfBenefit":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ExplanationOfBenefit":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Detail(FhirBaseModel):
    """The second-tier service adjudications for payor added services.:param int detailSequence: Detail sequence number
    :param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept productOrService: Billing, service, product, or drug code
    :param CodeableConcept modifier: Service/Product billing modifiers
    :param Quantity quantity: Count of products or services
    :param Money unitPrice: Fee, charge or cost per item
    :param float factor: Price scaling factor
    :param Money net: Total item cost
    :param int noteNumber: Applicable note numbers
    :param Adjudication adjudication: Added items adjudication
    :param SubDetail subDetail: Insurer added line items
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "productOrService": {"class_name": "CodeableConcept", "is_contained": False},
        "modifier": {"class_name": "CodeableConcept", "is_contained": False},
        "quantity": {"class_name": "Quantity", "is_contained": False},
        "unitPrice": {"class_name": "Money", "is_contained": False},
        "net": {"class_name": "Money", "is_contained": False},
        "adjudication": {"class_name": "Adjudication", "is_contained": True},
        "subDetail": {"class_name": "SubDetail", "is_contained": True},
    }

    def __init__(
        self,
        detailSequence: list["int"] = None,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        productOrService: "CodeableConcept" = None,
        modifier: list["CodeableConcept"] = None,
        quantity: "Quantity" = None,
        unitPrice: "Money" = None,
        factor: "float" = None,
        net: "Money" = None,
        noteNumber: list["int"] = None,
        adjudication: list["Adjudication"] = None,
        subDetail: list["SubDetail"] = None,
    ):
        self.detailSequence = detailSequence or []
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.productOrService = productOrService
        self.modifier = modifier or []
        self.quantity = quantity
        self.unitPrice = unitPrice
        self.factor = factor
        self.net = net
        self.noteNumber = noteNumber or []
        self.adjudication = adjudication or []
        self.subDetail = subDetail or []

    @classmethod
    def from_dict(cls, data: dict) -> "ExplanationOfBenefit":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ExplanationOfBenefit":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class AddItem(FhirBaseModel):
    """The first-tier service adjudications for payor added product or service lines.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param int itemSequence: Item sequence number
    :param int detailSequence: Detail sequence number
    :param int subDetailSequence: Subdetail sequence number
    :param Reference provider: Authorized providers
    :param CodeableConcept productOrService: Billing, service, product, or drug code
    :param CodeableConcept modifier: Service/Product billing modifiers
    :param CodeableConcept programCode: Program the product or service is provided under
    :param str servicedDate: Date or dates of service or product delivery
    :param Period servicedPeriod: Date or dates of service or product delivery
    :param CodeableConcept locationCodeableConcept: Place of service or where product was supplied
    :param Address locationAddress: Place of service or where product was supplied
    :param Reference locationReference: Place of service or where product was supplied
    :param Quantity quantity: Count of products or services
    :param Money unitPrice: Fee, charge or cost per item
    :param float factor: Price scaling factor
    :param Money net: Total item cost
    :param CodeableConcept bodySite: Anatomical location
    :param CodeableConcept subSite: Anatomical sub-location
    :param int noteNumber: Applicable note numbers
    :param Adjudication adjudication: Added items adjudication
    :param Detail detail: Insurer added line items
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "provider": {"class_name": "Reference", "is_contained": False},
        "productOrService": {"class_name": "CodeableConcept", "is_contained": False},
        "modifier": {"class_name": "CodeableConcept", "is_contained": False},
        "programCode": {"class_name": "CodeableConcept", "is_contained": False},
        "servicedPeriod": {"class_name": "Period", "is_contained": False},
        "locationCodeableConcept": {
            "class_name": "CodeableConcept",
            "is_contained": False,
        },
        "locationAddress": {"class_name": "Address", "is_contained": False},
        "locationReference": {"class_name": "Reference", "is_contained": False},
        "quantity": {"class_name": "Quantity", "is_contained": False},
        "unitPrice": {"class_name": "Money", "is_contained": False},
        "net": {"class_name": "Money", "is_contained": False},
        "bodySite": {"class_name": "CodeableConcept", "is_contained": False},
        "subSite": {"class_name": "CodeableConcept", "is_contained": False},
        "adjudication": {"class_name": "Adjudication", "is_contained": True},
        "detail": {"class_name": "Detail", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        itemSequence: list["int"] = None,
        detailSequence: list["int"] = None,
        subDetailSequence: list["int"] = None,
        provider: list["Reference"] = None,
        productOrService: "CodeableConcept" = None,
        modifier: list["CodeableConcept"] = None,
        programCode: list["CodeableConcept"] = None,
        servicedDate: "str" = None,
        servicedPeriod: "Period" = None,
        locationCodeableConcept: "CodeableConcept" = None,
        locationAddress: "Address" = None,
        locationReference: "Reference" = None,
        quantity: "Quantity" = None,
        unitPrice: "Money" = None,
        factor: "float" = None,
        net: "Money" = None,
        bodySite: "CodeableConcept" = None,
        subSite: list["CodeableConcept"] = None,
        noteNumber: list["int"] = None,
        adjudication: list["Adjudication"] = None,
        detail: list["Detail"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.itemSequence = itemSequence or []
        self.detailSequence = detailSequence or []
        self.subDetailSequence = subDetailSequence or []
        self.provider = provider or []
        self.productOrService = productOrService
        self.modifier = modifier or []
        self.programCode = programCode or []
        self.servicedDate = servicedDate
        self.servicedPeriod = servicedPeriod
        self.locationCodeableConcept = locationCodeableConcept
        self.locationAddress = locationAddress
        self.locationReference = locationReference
        self.quantity = quantity
        self.unitPrice = unitPrice
        self.factor = factor
        self.net = net
        self.bodySite = bodySite
        self.subSite = subSite or []
        self.noteNumber = noteNumber or []
        self.adjudication = adjudication or []
        self.detail = detail or []

    @classmethod
    def from_dict(cls, data: dict) -> "ExplanationOfBenefit":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ExplanationOfBenefit":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Total(FhirBaseModel):
    """Categorized monetary totals for the adjudication.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept category: Type of adjudication information
    :param Money amount: Financial total for the category
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "category": {"class_name": "CodeableConcept", "is_contained": False},
        "amount": {"class_name": "Money", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        category: "CodeableConcept" = None,
        amount: "Money" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.category = category
        self.amount = amount

    @classmethod
    def from_dict(cls, data: dict) -> "ExplanationOfBenefit":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ExplanationOfBenefit":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Payment(FhirBaseModel):
    """Payment details for the adjudication of the claim.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept type: Partial or complete payment
    :param Money adjustment: Payment adjustment for non-claim issues
    :param CodeableConcept adjustmentReason: Explanation for the variance
    :param str date: Expected date of payment
    :param Money amount: Payable amount after adjustment
    :param Identifier identifier: Business identifier for the payment
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "adjustment": {"class_name": "Money", "is_contained": False},
        "adjustmentReason": {"class_name": "CodeableConcept", "is_contained": False},
        "amount": {"class_name": "Money", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        type: "CodeableConcept" = None,
        adjustment: "Money" = None,
        adjustmentReason: "CodeableConcept" = None,
        date: "str" = None,
        amount: "Money" = None,
        identifier: "Identifier" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.type = type
        self.adjustment = adjustment
        self.adjustmentReason = adjustmentReason
        self.date = date
        self.amount = amount
        self.identifier = identifier

    @classmethod
    def from_dict(cls, data: dict) -> "ExplanationOfBenefit":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ExplanationOfBenefit":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class ProcessNote(FhirBaseModel):
    """A note that describes or explains adjudication results in a human readable form.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param int number: Note instance identifier
    :param str type: display | print | printoper
    :param str text: Note explanatory text
    :param CodeableConcept language: Language of the text
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "language": {"class_name": "CodeableConcept", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        number: "int" = None,
        type: "str" = None,
        text: "str" = None,
        language: "CodeableConcept" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.number = number
        self.type = type
        self.text = text
        self.language = language

    @classmethod
    def from_dict(cls, data: dict) -> "ExplanationOfBenefit":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ExplanationOfBenefit":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Financial(FhirBaseModel):
    """Benefits Used to date.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept type: Benefit classification
    :param int allowedUnsignedInt: Benefits allowed
    :param str allowedString: Benefits allowed
    :param Money allowedMoney: Benefits allowed
    :param int usedUnsignedInt: Benefits used
    :param Money usedMoney: Benefits used
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "allowedMoney": {"class_name": "Money", "is_contained": False},
        "usedMoney": {"class_name": "Money", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        type: "CodeableConcept" = None,
        allowedUnsignedInt: "int" = None,
        allowedString: "str" = None,
        allowedMoney: "Money" = None,
        usedUnsignedInt: "int" = None,
        usedMoney: "Money" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.type = type
        self.allowedUnsignedInt = allowedUnsignedInt
        self.allowedString = allowedString
        self.allowedMoney = allowedMoney
        self.usedUnsignedInt = usedUnsignedInt
        self.usedMoney = usedMoney

    @classmethod
    def from_dict(cls, data: dict) -> "ExplanationOfBenefit":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ExplanationOfBenefit":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class BenefitBalance(FhirBaseModel):
    """Balance by Benefit Category.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept category: Benefit classification
    :param bool excluded: Excluded from the plan
    :param str name: Short name for the benefit
    :param str description: Description of the benefit or services covered
    :param CodeableConcept network: In or out of network
    :param CodeableConcept unit: Individual or family
    :param CodeableConcept term: Annual or lifetime
    :param Financial financial: Benefit Summary
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "category": {"class_name": "CodeableConcept", "is_contained": False},
        "network": {"class_name": "CodeableConcept", "is_contained": False},
        "unit": {"class_name": "CodeableConcept", "is_contained": False},
        "term": {"class_name": "CodeableConcept", "is_contained": False},
        "financial": {"class_name": "Financial", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        category: "CodeableConcept" = None,
        excluded: "bool" = None,
        name: "str" = None,
        description: "str" = None,
        network: "CodeableConcept" = None,
        unit: "CodeableConcept" = None,
        term: "CodeableConcept" = None,
        financial: list["Financial"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.category = category
        self.excluded = excluded
        self.name = name
        self.description = description
        self.network = network
        self.unit = unit
        self.term = term
        self.financial = financial or []

    @classmethod
    def from_dict(cls, data: dict) -> "ExplanationOfBenefit":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ExplanationOfBenefit":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class ExplanationOfBenefit(DomainResource):
    """This resource provides: the claim details; adjudication details from the processing of a Claim; and optionally account balance information, for informing the subscriber of the benefits provided.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param Identifier identifier: Business Identifier for the resource
    :param str status: active | cancelled | draft | entered-in-error
    :param CodeableConcept type: Category or discipline
    :param CodeableConcept subType: More granular claim type
    :param str use: claim | preauthorization | predetermination
    :param Reference patient: The recipient of the products and services
    :param Period billablePeriod: Relevant time frame for the claim
    :param str created: Response creation date
    :param Reference enterer: Author of the claim
    :param Reference insurer: Party responsible for reimbursement
    :param Reference provider: Party responsible for the claim
    :param CodeableConcept priority: Desired processing urgency
    :param CodeableConcept fundsReserveRequested: For whom to reserve funds
    :param CodeableConcept fundsReserve: Funds reserved status
    :param Related related: Prior or corollary claims
    :param Reference prescription: Prescription authorizing services or products
    :param Reference originalPrescription: Original prescription if superceded by fulfiller
    :param Payee payee: Recipient of benefits payable
    :param Reference referral: Treatment Referral
    :param Reference facility: Servicing Facility
    :param Reference claim: Claim reference
    :param Reference claimResponse: Claim response reference
    :param str outcome: queued | complete | error | partial
    :param str disposition: Disposition Message
    :param str preAuthRef: Preauthorization reference
    :param Period preAuthRefPeriod: Preauthorization in-effect period
    :param CareTeam careTeam: Care Team members
    :param SupportingInfo supportingInfo: Supporting information
    :param Diagnosis diagnosis: Pertinent diagnosis information
    :param Procedure procedure: Clinical procedures performed
    :param int precedence: Precedence (primary, secondary, etc.)
    :param Insurance insurance: Patient insurance information
    :param Accident accident: Details of the event
    :param Item item: Product or service provided
    :param AddItem addItem: Insurer added line items
    :param Adjudication adjudication: Header-level adjudication
    :param Total total: Adjudication totals
    :param Payment payment: Payment Details
    :param CodeableConcept formCode: Printed form identifier
    :param Attachment form: Printed reference or actual form
    :param ProcessNote processNote: Note concerning adjudication
    :param Period benefitPeriod: When the benefits are applicable
    :param BenefitBalance benefitBalance: Balance by Benefit Category
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "subType": {"class_name": "CodeableConcept", "is_contained": False},
        "patient": {"class_name": "Reference", "is_contained": False},
        "billablePeriod": {"class_name": "Period", "is_contained": False},
        "enterer": {"class_name": "Reference", "is_contained": False},
        "insurer": {"class_name": "Reference", "is_contained": False},
        "provider": {"class_name": "Reference", "is_contained": False},
        "priority": {"class_name": "CodeableConcept", "is_contained": False},
        "fundsReserveRequested": {
            "class_name": "CodeableConcept",
            "is_contained": False,
        },
        "fundsReserve": {"class_name": "CodeableConcept", "is_contained": False},
        "related": {"class_name": "Related", "is_contained": True},
        "prescription": {"class_name": "Reference", "is_contained": False},
        "originalPrescription": {"class_name": "Reference", "is_contained": False},
        "payee": {"class_name": "Payee", "is_contained": True},
        "referral": {"class_name": "Reference", "is_contained": False},
        "facility": {"class_name": "Reference", "is_contained": False},
        "claim": {"class_name": "Reference", "is_contained": False},
        "claimResponse": {"class_name": "Reference", "is_contained": False},
        "preAuthRefPeriod": {"class_name": "Period", "is_contained": False},
        "careTeam": {"class_name": "CareTeam", "is_contained": True},
        "supportingInfo": {"class_name": "SupportingInfo", "is_contained": True},
        "diagnosis": {"class_name": "Diagnosis", "is_contained": True},
        "procedure": {"class_name": "Procedure", "is_contained": True},
        "insurance": {"class_name": "Insurance", "is_contained": True},
        "accident": {"class_name": "Accident", "is_contained": True},
        "item": {"class_name": "Item", "is_contained": True},
        "addItem": {"class_name": "AddItem", "is_contained": True},
        "adjudication": {"class_name": "Adjudication", "is_contained": True},
        "total": {"class_name": "Total", "is_contained": True},
        "payment": {"class_name": "Payment", "is_contained": True},
        "formCode": {"class_name": "CodeableConcept", "is_contained": False},
        "form": {"class_name": "Attachment", "is_contained": False},
        "processNote": {"class_name": "ProcessNote", "is_contained": True},
        "benefitPeriod": {"class_name": "Period", "is_contained": False},
        "benefitBalance": {"class_name": "BenefitBalance", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        identifier: list["Identifier"] = None,
        status: "str" = None,
        type: "CodeableConcept" = None,
        subType: "CodeableConcept" = None,
        use: "str" = None,
        patient: "Reference" = None,
        billablePeriod: "Period" = None,
        created: "str" = None,
        enterer: "Reference" = None,
        insurer: "Reference" = None,
        provider: "Reference" = None,
        priority: "CodeableConcept" = None,
        fundsReserveRequested: "CodeableConcept" = None,
        fundsReserve: "CodeableConcept" = None,
        related: list["Related"] = None,
        prescription: "Reference" = None,
        originalPrescription: "Reference" = None,
        payee: "Payee" = None,
        referral: "Reference" = None,
        facility: "Reference" = None,
        claim: "Reference" = None,
        claimResponse: "Reference" = None,
        outcome: "str" = None,
        disposition: "str" = None,
        preAuthRef: list["str"] = None,
        preAuthRefPeriod: list["Period"] = None,
        careTeam: list["CareTeam"] = None,
        supportingInfo: list["SupportingInfo"] = None,
        diagnosis: list["Diagnosis"] = None,
        procedure: list["Procedure"] = None,
        precedence: "int" = None,
        insurance: list["Insurance"] = None,
        accident: "Accident" = None,
        item: list["Item"] = None,
        addItem: list["AddItem"] = None,
        adjudication: list["Adjudication"] = None,
        total: list["Total"] = None,
        payment: "Payment" = None,
        formCode: "CodeableConcept" = None,
        form: "Attachment" = None,
        processNote: list["ProcessNote"] = None,
        benefitPeriod: "Period" = None,
        benefitBalance: list["BenefitBalance"] = None,
    ):

        self.resourceType = "ExplanationOfBenefit"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.identifier = identifier or []
        self.status = status
        self.type = type
        self.subType = subType
        self.use = use
        self.patient = patient
        self.billablePeriod = billablePeriod
        self.created = created
        self.enterer = enterer
        self.insurer = insurer
        self.provider = provider
        self.priority = priority
        self.fundsReserveRequested = fundsReserveRequested
        self.fundsReserve = fundsReserve
        self.related = related or []
        self.prescription = prescription
        self.originalPrescription = originalPrescription
        self.payee = payee
        self.referral = referral
        self.facility = facility
        self.claim = claim
        self.claimResponse = claimResponse
        self.outcome = outcome
        self.disposition = disposition
        self.preAuthRef = preAuthRef or []
        self.preAuthRefPeriod = preAuthRefPeriod or []
        self.careTeam = careTeam or []
        self.supportingInfo = supportingInfo or []
        self.diagnosis = diagnosis or []
        self.procedure = procedure or []
        self.precedence = precedence
        self.insurance = insurance or []
        self.accident = accident
        self.item = item or []
        self.addItem = addItem or []
        self.adjudication = adjudication or []
        self.total = total or []
        self.payment = payment
        self.formCode = formCode
        self.form = form
        self.processNote = processNote or []
        self.benefitPeriod = benefitPeriod
        self.benefitBalance = benefitBalance or []

    @classmethod
    def from_dict(cls, data: dict) -> "ExplanationOfBenefit":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ExplanationOfBenefit":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for Coverage. 
Time: 2024-06-14 18:37:49
"""

from fhirmodels.R4B.BackboneElement import *
from fhirmodels.R4B.CodeableConcept import *
from fhirmodels.R4B.DomainResource import *
from fhirmodels.R4B.Extension import *
from fhirmodels.R4B.Identifier import *
from fhirmodels.R4B.Meta import *
from fhirmodels.R4B.Money import *
from fhirmodels.R4B.Narrative import *
from fhirmodels.R4B.Period import *
from fhirmodels.R4B.Quantity import *
from fhirmodels.R4B.Reference import *
from fhirmodels.R4B.Resource import *


class _class(FhirBaseModel):
    """A suite of underwriter specific classifiers.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept type: Type of class such as 'group' or 'plan'
    :param str value: Value associated with the type
    :param str name: Human readable description of the type and value
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        type: "CodeableConcept" = None,
        value: "str" = None,
        name: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.type = type
        self.value = value
        self.name = name

    @classmethod
    def from_dict(cls, data: dict) -> "Coverage":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Coverage":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Exception(FhirBaseModel):
    """A suite of codes indicating exceptions or reductions to patient costs and their effective periods.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept type: Exception category
    :param Period period: The effective period of the exception
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "period": {"class_name": "Period", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        type: "CodeableConcept" = None,
        period: "Period" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.type = type
        self.period = period

    @classmethod
    def from_dict(cls, data: dict) -> "Coverage":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Coverage":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class CostToBeneficiary(FhirBaseModel):
    """A suite of codes indicating the cost category and associated amount which have been detailed in the policy and may have been  included on the health card.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept type: Cost category
    :param Quantity valueQuantity: The amount or percentage due from the beneficiary
    :param Money valueMoney: The amount or percentage due from the beneficiary
    :param Exception exception: Exceptions for patient payments
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "valueQuantity": {"class_name": "Quantity", "is_contained": False},
        "valueMoney": {"class_name": "Money", "is_contained": False},
        "exception": {"class_name": "Exception", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        type: "CodeableConcept" = None,
        valueQuantity: "Quantity" = None,
        valueMoney: "Money" = None,
        exception: list["Exception"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.type = type
        self.valueQuantity = valueQuantity
        self.valueMoney = valueMoney
        self.exception = exception or []

    @classmethod
    def from_dict(cls, data: dict) -> "Coverage":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Coverage":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Coverage(DomainResource):
    """Financial instrument which may be used to reimburse or pay for health care products and services. Includes both insurance and self-payment.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param Identifier identifier: Business Identifier for the coverage
    :param str status: active | cancelled | draft | entered-in-error
    :param CodeableConcept type: Coverage category such as medical or accident
    :param Reference policyHolder: Owner of the policy
    :param Reference subscriber: Subscriber to the policy
    :param str subscriberId: ID assigned to the subscriber
    :param Reference beneficiary: Plan beneficiary
    :param str dependent: Dependent number
    :param CodeableConcept relationship: Beneficiary relationship to the subscriber
    :param Period period: Coverage start and end dates
    :param Reference payor: Issuer of the policy
    :param _class _class: Additional coverage classifications
    :param int order: Relative order of the coverage
    :param str network: Insurer network
    :param CostToBeneficiary costToBeneficiary: Patient payments for services/products
    :param bool subrogation: Reimbursement to insurer
    :param Reference contract: Contract details
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "policyHolder": {"class_name": "Reference", "is_contained": False},
        "subscriber": {"class_name": "Reference", "is_contained": False},
        "beneficiary": {"class_name": "Reference", "is_contained": False},
        "relationship": {"class_name": "CodeableConcept", "is_contained": False},
        "period": {"class_name": "Period", "is_contained": False},
        "payor": {"class_name": "Reference", "is_contained": False},
        "_class": {"class_name": "_class", "is_contained": True},
        "costToBeneficiary": {"class_name": "CostToBeneficiary", "is_contained": True},
        "contract": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        identifier: list["Identifier"] = None,
        status: "str" = None,
        type: "CodeableConcept" = None,
        policyHolder: "Reference" = None,
        subscriber: "Reference" = None,
        subscriberId: "str" = None,
        beneficiary: "Reference" = None,
        dependent: "str" = None,
        relationship: "CodeableConcept" = None,
        period: "Period" = None,
        payor: list["Reference"] = None,
        _class: list["_class"] = None,
        order: "int" = None,
        network: "str" = None,
        costToBeneficiary: list["CostToBeneficiary"] = None,
        subrogation: "bool" = None,
        contract: list["Reference"] = None,
    ):

        self.resourceType = "Coverage"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.identifier = identifier or []
        self.status = status
        self.type = type
        self.policyHolder = policyHolder
        self.subscriber = subscriber
        self.subscriberId = subscriberId
        self.beneficiary = beneficiary
        self.dependent = dependent
        self.relationship = relationship
        self.period = period
        self.payor = payor or []
        self._class = _class or []
        self.order = order
        self.network = network
        self.costToBeneficiary = costToBeneficiary or []
        self.subrogation = subrogation
        self.contract = contract or []

    @classmethod
    def from_dict(cls, data: dict) -> "Coverage":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Coverage":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for GenomicStudy. 
Time: 2024-06-14 18:37:55
"""

from fhirmodels.R5.Annotation import *
from fhirmodels.R5.BackboneElement import *
from fhirmodels.R5.CodeableConcept import *
from fhirmodels.R5.CodeableReference import *
from fhirmodels.R5.DomainResource import *
from fhirmodels.R5.Extension import *
from fhirmodels.R5.Identifier import *
from fhirmodels.R5.Meta import *
from fhirmodels.R5.Narrative import *
from fhirmodels.R5.Reference import *
from fhirmodels.R5.Resource import *


class Input(FhirBaseModel):
    """Inputs for the analysis event.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param Reference file: File containing input data
    :param CodeableConcept type: Type of input data (e.g., BAM, CRAM, or FASTA)
    :param Identifier generatedByIdentifier: The analysis event or other GenomicStudy that generated this input file
    :param Reference generatedByReference: The analysis event or other GenomicStudy that generated this input file
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "file": {"class_name": "Reference", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "generatedByIdentifier": {"class_name": "Identifier", "is_contained": False},
        "generatedByReference": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        file: "Reference" = None,
        type: "CodeableConcept" = None,
        generatedByIdentifier: "Identifier" = None,
        generatedByReference: "Reference" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.file = file
        self.type = type
        self.generatedByIdentifier = generatedByIdentifier
        self.generatedByReference = generatedByReference

    @classmethod
    def from_dict(cls, data: dict) -> "GenomicStudy":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "GenomicStudy":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Output(FhirBaseModel):
    """Outputs for the analysis event.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param Reference file: File containing output data
    :param CodeableConcept type: Type of output data (e.g., VCF, MAF, or BAM)
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "file": {"class_name": "Reference", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        file: "Reference" = None,
        type: "CodeableConcept" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.file = file
        self.type = type

    @classmethod
    def from_dict(cls, data: dict) -> "GenomicStudy":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "GenomicStudy":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Performer(FhirBaseModel):
    """Performer for the analysis event.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param Reference actor: The organization, healthcare professional, or others who participated in performing this analysis
    :param CodeableConcept role: Role of the actor for this analysis
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "actor": {"class_name": "Reference", "is_contained": False},
        "role": {"class_name": "CodeableConcept", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        actor: "Reference" = None,
        role: "CodeableConcept" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.actor = actor
        self.role = role

    @classmethod
    def from_dict(cls, data: dict) -> "GenomicStudy":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "GenomicStudy":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Device(FhirBaseModel):
    """Devices used for the analysis (e.g., instruments, software), with settings and parameters.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param Reference device: Device used for the analysis
    :param CodeableConcept function: Specific function for the device used for the analysis
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "device": {"class_name": "Reference", "is_contained": False},
        "function": {"class_name": "CodeableConcept", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        device: "Reference" = None,
        function: "CodeableConcept" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.device = device
        self.function = function

    @classmethod
    def from_dict(cls, data: dict) -> "GenomicStudy":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "GenomicStudy":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Analysis(FhirBaseModel):
    """The details about a specific analysis that was performed in this GenomicStudy.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param Identifier identifier: Identifiers for the analysis event
    :param CodeableConcept methodType: Type of the methods used in the analysis (e.g., FISH, Karyotyping, MSI)
    :param CodeableConcept changeType: Type of the genomic changes studied in the analysis (e.g., DNA, RNA, or AA change)
    :param CodeableConcept genomeBuild: Genome build that is used in this analysis
    :param str instantiatesCanonical: The defined protocol that describes the analysis
    :param str instantiatesUri: The URL pointing to an externally maintained protocol that describes the analysis
    :param str title: Name of the analysis event (human friendly)
    :param Reference focus: What the genomic analysis is about, when it is not about the subject of record
    :param Reference specimen: The specimen used in the analysis event
    :param str date: The date of the analysis event
    :param Annotation note: Any notes capture with the analysis event
    :param Reference protocolPerformed: The protocol that was performed for the analysis event
    :param Reference regionsStudied: The genomic regions to be studied in the analysis (BED file)
    :param Reference regionsCalled: Genomic regions actually called in the analysis event (BED file)
    :param Input input: Inputs for the analysis event
    :param Output output: Outputs for the analysis event
    :param Performer performer: Performer for the analysis event
    :param Device device: Devices used for the analysis (e.g., instruments, software), with settings and parameters
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "methodType": {"class_name": "CodeableConcept", "is_contained": False},
        "changeType": {"class_name": "CodeableConcept", "is_contained": False},
        "genomeBuild": {"class_name": "CodeableConcept", "is_contained": False},
        "focus": {"class_name": "Reference", "is_contained": False},
        "specimen": {"class_name": "Reference", "is_contained": False},
        "note": {"class_name": "Annotation", "is_contained": False},
        "protocolPerformed": {"class_name": "Reference", "is_contained": False},
        "regionsStudied": {"class_name": "Reference", "is_contained": False},
        "regionsCalled": {"class_name": "Reference", "is_contained": False},
        "input": {"class_name": "Input", "is_contained": True},
        "output": {"class_name": "Output", "is_contained": True},
        "performer": {"class_name": "Performer", "is_contained": True},
        "device": {"class_name": "Device", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        identifier: list["Identifier"] = None,
        methodType: list["CodeableConcept"] = None,
        changeType: list["CodeableConcept"] = None,
        genomeBuild: "CodeableConcept" = None,
        instantiatesCanonical: "str" = None,
        instantiatesUri: "str" = None,
        title: "str" = None,
        focus: list["Reference"] = None,
        specimen: list["Reference"] = None,
        date: "str" = None,
        note: list["Annotation"] = None,
        protocolPerformed: "Reference" = None,
        regionsStudied: list["Reference"] = None,
        regionsCalled: list["Reference"] = None,
        input: list["Input"] = None,
        output: list["Output"] = None,
        performer: list["Performer"] = None,
        device: list["Device"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.identifier = identifier or []
        self.methodType = methodType or []
        self.changeType = changeType or []
        self.genomeBuild = genomeBuild
        self.instantiatesCanonical = instantiatesCanonical
        self.instantiatesUri = instantiatesUri
        self.title = title
        self.focus = focus or []
        self.specimen = specimen or []
        self.date = date
        self.note = note or []
        self.protocolPerformed = protocolPerformed
        self.regionsStudied = regionsStudied or []
        self.regionsCalled = regionsCalled or []
        self.input = input or []
        self.output = output or []
        self.performer = performer or []
        self.device = device or []

    @classmethod
    def from_dict(cls, data: dict) -> "GenomicStudy":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "GenomicStudy":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class GenomicStudy(DomainResource):
    """A set of analyses performed to analyze and generate genomic data.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param Identifier identifier: Identifiers for this genomic study
    :param str status: registered | available | cancelled | entered-in-error | unknown
    :param CodeableConcept type: The type of the study (e.g., Familial variant segregation, Functional variation detection, or Gene expression profiling)
    :param Reference subject: The primary subject of the genomic study
    :param Reference encounter: The healthcare event with which this genomics study is associated
    :param str startDate: When the genomic study was started
    :param Reference basedOn: Event resources that the genomic study is based on
    :param Reference referrer: Healthcare professional who requested or referred the genomic study
    :param Reference interpreter: Healthcare professionals who interpreted the genomic study
    :param CodeableReference reason: Why the genomic study was performed
    :param str instantiatesCanonical: The defined protocol that describes the study
    :param str instantiatesUri: The URL pointing to an externally maintained protocol that describes the study
    :param Annotation note: Comments related to the genomic study
    :param str description: Description of the genomic study
    :param Analysis analysis: Genomic Analysis Event
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "subject": {"class_name": "Reference", "is_contained": False},
        "encounter": {"class_name": "Reference", "is_contained": False},
        "basedOn": {"class_name": "Reference", "is_contained": False},
        "referrer": {"class_name": "Reference", "is_contained": False},
        "interpreter": {"class_name": "Reference", "is_contained": False},
        "reason": {"class_name": "CodeableReference", "is_contained": False},
        "note": {"class_name": "Annotation", "is_contained": False},
        "analysis": {"class_name": "Analysis", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        identifier: list["Identifier"] = None,
        status: "str" = None,
        type: list["CodeableConcept"] = None,
        subject: "Reference" = None,
        encounter: "Reference" = None,
        startDate: "str" = None,
        basedOn: list["Reference"] = None,
        referrer: "Reference" = None,
        interpreter: list["Reference"] = None,
        reason: list["CodeableReference"] = None,
        instantiatesCanonical: "str" = None,
        instantiatesUri: "str" = None,
        note: list["Annotation"] = None,
        description: "str" = None,
        analysis: list["Analysis"] = None,
    ):

        self.resourceType = "GenomicStudy"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.identifier = identifier or []
        self.status = status
        self.type = type or []
        self.subject = subject
        self.encounter = encounter
        self.startDate = startDate
        self.basedOn = basedOn or []
        self.referrer = referrer
        self.interpreter = interpreter or []
        self.reason = reason or []
        self.instantiatesCanonical = instantiatesCanonical
        self.instantiatesUri = instantiatesUri
        self.note = note or []
        self.description = description
        self.analysis = analysis or []

    @classmethod
    def from_dict(cls, data: dict) -> "GenomicStudy":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "GenomicStudy":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()
